@@ -11,18 +11,20 @@ use Net::Curl::Easy qw(:constants);
 
 use MyServer;
 
-our $TEST_COUNT = 6;
+use constant _paths => qw( foo bar biggie baz qux quux );
+
+our $TEST_COUNT = 2 * _paths();
 
 sub run {
     my ($promiser, $port) = @_;
 
-    my @paths = qw( foo bar biggie );
-
     my @promises = map {
         my $path = $_;
         my $easy = Net::Curl::Easy->new();
         $easy->setopt( CURLOPT_URL() => "http://127.0.0.1:$port/$path" );
 
+        # $easy->setopt( CURLOPT_VERBOSE() => 1 );
+
         $_ = q<> for @{$easy}{ qw(_head _body) };
         $easy->setopt( CURLOPT_HEADERDATA() => \$easy->{'_head'} );
         $easy->setopt( CURLOPT_FILE() => \$easy->{'_body'} );
@@ -30,7 +32,7 @@ sub run {
         $promiser->add_handle($easy)->then( sub {
             my ($easy) = shift;
 
-            is($easy->{'_head'}, $MyServer::HEAD, "headers: $path" );
+            like($easy->{'_head'}, qr<\A$MyServer::HEAD_START>, "headers: $path" );
 
             if ($path eq 'biggie') {
                 is( $easy->{'_body'}, $MyServer::BIGGIE, "payload: $path" );
@@ -38,8 +40,8 @@ sub run {
             else {
                 is( $easy->{'_body'}, "/$path", "payload: $path" );
             }
-        } );
-    } @paths;
+        }, sub { warn "REJECT $path: @_\n" } );
+    } _paths();
 
     return Promise::ES6->all(\@promises);
 }
